#!/bin/bash

package=tesseract
version=-5.0.0

progname=$0

source ../cascade-make/lib/cascade-lib.bash GEXTTESS ../.. $*

prefix=$GEXTTESS_INSTALLED

# See imagemagick ext
if [ "x$CROSSCONFIGURE_ARGS" != "x" ] ; then
    echo "WARNING: Crossconfiguring not supported yet"
fi

export CFLAGS="$CFLAGS -I$GEXTTESS_INSTALLED/include"
export CPPFLAGS="$CPPFLAGS -I$GEXTTESS_INSTALLED/include"
export CXXFLAGS="$CXXFLAGS -I$GEXTTESS_INSTALLED/include"
export LDFLAGS="$LDFLAGS -L$GEXTTESS_INSTALLED/lib"
export LD_LIBRARY_PATH="$GEXTTESS_INSTALLED/lib"
# Need PKG_CONFIG_PATH set tp leptonica's lib/pkgconfig folder (containing lept.pc file)
export PKG_CONFIG_PATH=$GEXTTESS_INSTALLED/lib/pkgconfig

opt_run_untar $force_untar $auto_untar $package $version

# Need to do this for TESSERACT, before we can do configure->make->make install
pushd $package$version;
libtoolize
#aclocal
#autoheader
sh autogen.sh
popd

opt_run_configure $force_config $auto_config $package $version $prefix \
  --disable-shared --enable-static

opt_run_make $compile $package $version
opt_run_make $install $package $version "install"
opt_run_make $clean $package $version "clean"
opt_run_make $distclean $package $version "distclean"

opt_run_tarclean $tarclean $package $version


echo "Installing basic tesseract languages support (tessdata)"
cp $GEXTTESS_DEVEL/packages/tessdata-langs.tar.gz $GEXTTESS_INSTALLED/.
pushd $GEXTTESS_INSTALLED
tar -xvzf tessdata-langs.tar.gz
rm tessdata-langs.tar.gz
mkdir -p tessdata/tessconfigs
popd

# Not sure why source package's tessdata didn't get installed in installdir
# despite exporting TESSDATA_PREFIX at the start at cascade-make process.
cp -r $package$version/tessdata/configs $GEXTTESS_INSTALLED/tessdata/
cp $package$version/tessdata/eng.user-patterns $GEXTTESS_INSTALLED/tessdata/.
cp $package$version/tessdata/eng.user-words $GEXTTESS_INSTALLED/tessdata/.
cp $package$version/tessdata/tessconfigs/*batch* $GEXTTESS_INSTALLED/tessdata/tessconfigs/.
cp $package$version/tessdata/tessconfigs/*demo* $GEXTTESS_INSTALLED/tessdata/tessconfigs/.


echo "Done installing basic tesseract languages"
echo "Visit https://github.com/tesseract-ocr/tessdata for a full list of trained language data."
echo "To download support for any specific language(s), note the 3 letter code of that language"
echo "Go into your $GEXTTESS_INSTALLED/tessdata and for each language run: "
echo "   wget https://github.com/tesseract-ocr/tessdata/raw/master/<3-letter-lang-code>.traineddata"
echo "To get all languages currently supported by Tesseract, delete"
echo "$GEXTTESS_INSTALLED/tessdata"
echo "and in $GEXTTES_INSTALLED run:"
echo "   git clone https://github.com/tesseract-ocr/tessdata"
echo ""
